@@ -155,17 +155,10 @@ with the appropriate XHTML minimized tag syntax. For example:
 <p></p>
 <br />
 
-Installation
-------------
-
-Under Python 2 you should just ``python setup.py install`` but under Python
-3 you will need to ``python3 setup.py build install`` -- note the
-additional **build** command.
-
-
 Version History (in Brief)
 --------------------------
 
+- 1.10 support plain ol' distutils again
 - 1.9 added unicode support for Python 2.x
 - 1.8 added Python 3 compatibility
 - 1.7 added Python 2.5 compatibility and escape argument to tag
@@ -184,7 +177,7 @@ See the end of the source file for the license of use.
 XHTML support was contributed by Michael Haubenwallner.
 '''
 from __future__ import with_statement
-__version__ = '1.9'
+__version__ = '1.10'
 
 import unittest
 import cgi
